(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('prop-types'), require('react-router-dom')) :
	typeof define === 'function' && define.amd ? define(['exports', 'react', 'prop-types', 'react-router-dom'], factory) :
	(factory((global.ReactEnhancedRoute = {}),global.React,global.PropTypes,global.reactRouterDom));
}(this, (function (exports,React,PropTypes,reactRouterDom) { 'use strict';

React = React && React.hasOwnProperty('default') ? React['default'] : React;
PropTypes = PropTypes && PropTypes.hasOwnProperty('default') ? PropTypes['default'] : PropTypes;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

const EnhancedRoute = props => {

  const { component: Component, layout: Layout, redirect, auth: isAuthorized } = props,
        rest = _objectWithoutProperties(props, ['component', 'layout', 'redirect', 'auth']);

  /*
   If `auth <Boolean>` and `layout <ReactElement>` have not been provided
   as EnhancedRoute attribute then we return default
   react-router-dom Route.
   */
  if (!props.hasOwnProperty('auth') && !props.hasOwnProperty('layout')) return React.createElement(reactRouterDom.Route, props);

  /*
   Depending on whether we passed `layout <ReactElement>`
   attribute or not, we define template.
   */
  const template = Layout ? React.createElement(
    Layout,
    null,
    React.createElement(Component, null)
  ) : React.createElement(Component, null);

  /*
   If `layout <ReactElement>` has been provided and
   `auth <Boolean>` has not been provided we return
   Route wrapped in specified layout.
   */
  if (props.hasOwnProperty('layout') && !props.hasOwnProperty('auth')) return React.createElement(reactRouterDom.Route, _extends({}, rest, { component: () => template }));

  /*
   If we are not authorized we redirect to specified path
   or render default Unauthorized page.
   */
  if (!isAuthorized) {
    return redirect ? React.createElement(reactRouterDom.Redirect, { to: { pathname: redirect } }) : React.createElement(reactRouterDom.Route, { render: () => React.createElement(
        'div',
        null,
        'Unauthorized'
      ) });
  }

  /*
   If we reached this far it means we are authorized
   and we render protected route.
   */
  return React.createElement(reactRouterDom.Route, _extends({}, rest, { render: () => template }));
};

EnhancedRoute.propTypes = {
  component: PropTypes.func.isRequired,
  redirect: PropTypes.string,
  auth: PropTypes.bool,
  layout: PropTypes.func
};

exports.EnhancedRoute = EnhancedRoute;

Object.defineProperty(exports, '__esModule', { value: true });

})));
